<?php
/**
 * The template for displaying comments.
 *
 * The area of the page that contains both current comments
 * and the comment form.
 *
 * @package bloom
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
		<h2 class="comments-title">
			<?php
				printf( // WPCS: XSS OK.
					esc_html( _nx( 'One comment', '%1$s Comments', get_comments_number(), 'bloom-gumtheme' ) ),
					number_format_i18n( get_comments_number() )
				);
			?>
		</h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-above" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'bloom-gumtheme' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'bloom-gumtheme' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'bloom-gumtheme' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-above -->
		<?php endif; // Check for comment navigation. ?>

		<ul class="comment-list">
			<?php
				wp_list_comments( 'avatar_size=64&type=comment&callback=gum_comment');
			?>
		</ul><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'bloom-gumtheme' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'bloom-gumtheme' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'bloom-gumtheme' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-below -->
		<?php endif; // Check for comment navigation. ?>

	<?php endif; // Check for have_comments(). ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'bloom-gumtheme' ); ?></p>
	<?php endif; ?>

	<?php 
		$commenter = wp_get_current_commenter();
		$req = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );

		$args = array(
		    'fields' => apply_filters(
		        'comment_form_default_fields', array(
		            'author' =>'<p class="comment-form-author">' . '<input id="author" placeholder="NAME *" name="author" type="text" value="' .
		                esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' />'.'</p>'
		                ,
		            'email'  => '<p class="comment-form-email">' . '<input id="email" placeholder="EMAIL *" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
		                '" size="30"' . $aria_req . ' />'  .'</p>',
		            'url'    => '<p class="comment-form-url">' .
		             '<input id="url" name="url" placeholder="WEBSITE *" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) . '" size="30" /> ' .
		               '</p>'
		        )
		    ),
		    'comment_field' => '<p class="comment-form-comment">' .
		        '<textarea id="comment" name="comment" placeholder="YOUR COMMENT" cols="45" rows="6" aria-required="true"></textarea>' .
		        '</p>',
		    'comment_notes_after' => '',
		    'title_reply' => 'Leave a reply'
		);


	comment_form($args); ?>

</div><!-- #comments -->
