<?php
/**
 * Blocks Initializer
 *
 * Enqueue CSS/JS of all the blocks.
 *
 * @since   1.0.0
 * @package GUM
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Enqueue Gutenberg block assets for both frontend + backend.
 *
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function gumtheme_block_assets() { // phpcs:ignore
	// Styles.
	wp_enqueue_style(
		'my_block-cgb-style-css', // Handle.
		GUM_FRAMEWORK_PB_URL.'/dist/blocks.style.build.css', // Block style CSS.
		array( 'wp-editor' ) // Dependency to include the CSS after it.
		// filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.style.build.css' ) // Version: File modification time.
	);
}

// Hook: Frontend assets.
add_action( 'enqueue_block_assets', 'gumtheme_block_assets' );

/**
 * Enqueue Gutenberg block assets for backend editor.
 *
 * @uses {wp-blocks} for block type registration & related functions.
 * @uses {wp-element} for WP Element abstraction — structure of blocks.
 * @uses {wp-i18n} to internationalize the block's text.
 * @uses {wp-editor} for WP editor styles.
 * @since 1.0.0
 */
function gumtheme_editor_assets() { // phpcs:ignore
    // Scripts.
    $version = rand();
	wp_enqueue_script(
		'my_block-cgb-block-js', // Handle.
		GUM_FRAMEWORK_PB_URL.'/dist/blocks.build.js?'.$version, // Block.build.js: We register the block here. Built with Webpack.
		array( 'wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor' ), // Dependencies, defined above.
		//filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.build.js' ), // Version: File modification time.
		13,
		true // Enqueue the script in the footer.
	);

	// Styles.
	wp_enqueue_style(
		'my_block-cgb-block-editor-css', // Handle.
		GUM_FRAMEWORK_PB_URL.'/dist/blocks.editor.build.css?'.$version, // Block editor CSS.
		array( 'wp-edit-blocks' ) // Dependency to include the CSS after it.
		// filemtime( plugin_dir_path( __DIR__ ) . 'dist/blocks.editor.build.css' ) // Version: File modification time.
	);
}
// Hook: Editor assets.
add_action( 'enqueue_block_editor_assets', 'gumtheme_editor_assets' );

$grid_attributes = array(

    'gum_grid_title' => array(
        'type' => 'string',
    ),
    'gum_grid_title_link' => array(
        'type' => 'string',
    ),
    'post_sort_by' => array(
        'type' => 'string',
    ),
    'posts_per_page' => array(
        'type' => 'string',
    ),
    'gum_post_offset' => array(
        'type' => 'string',
    ),

    'select_sidebar' => array(
            'type' => 'string',
    ),
   'tag_filter' => array(
        'type' => 'string',
    ),
    'multi_cat_filter' => array(
        'type' => 'string',
    ),
    'author_filter' => array(
            'type' => 'string',
        ),

    'gum_ajax_filter_type' => array(
            'type' => 'string',
        ),

    'ajax_cat_filter_default_text' => array(
            'type' => 'string',
        ),

    'ajax_cat_filter' => array(
            'type' => 'string',
        ),

    'category_id' => array(
            'type' => 'string',
        ),

    'gum_grid_pagination' => array(
        'type' => 'string',
    ),
    'className' => array(
        'type' => 'string',
    ),
    'block_id' => array(
        'type' => 'string',
    )
    );
// if JS block attribute key is not same as php gum_html options key, JS-Key => PHP-Option_key
$other_mapping = [
    'block_id' => 'id',
    'select_sidebar' => 'sidebar'
];
$includes = [
    'post_grid_1.php',
    'post_grid_2.php',
    'post_grid_3.php',
    'post_grid_4.php',
//    'full_grid_1.php',
//    'full_grid_2.php',
//    'carousel_1.php',
    'full_slider_1.php',
    'sidebar.php',
    'posts_recent_posts.php',
//    'trending_posts.php',
    'single_post.php',
    'latest_posts.php'
];
foreach($includes as $inc_file)
    include(GUM_FRAMEWORK_PB_PATH.'/src/includes/'.$inc_file);
