<?php
/**
 * Gum_blog_html calss - HTML ouput for archive and blog page.
 * @author Gumthemes.com
 */
class Gum_blog_html {

	public $blog_options = array();
	public $cat_id = 0;
	public $page_builder = false;

	public $option_mapping = array(
		'cat' => array(
			'cat_color'=>'cat_color',
			'post_listing'=>'cat_post_listing',
			'show_excerpt' => 'cat_show_excerpt',
			'title_length' => 'cat_title_length',
			'show_name' => 'cat_show_name',
			'show_date' => 'cat_show_date',
			'date_type' => 'cat_date_type',
			'date_format' => 'cat_date_format',
			'date_pretext' => 'cat_post_date_pretext',
			'show_author' => 'cat_show_author',
			'show_views' => 'cat_show_views',
			'show_likes' => 'cat_show_likes',
			'show_comment_count' => 'cat_show_comment_count',
			'show_top_post_grid' => 'show_cat_top_post_grid',
			'top_post_style' => 'cat_top_post_style',
			'sidebar_position' => 'cat_sidebar_position',
			'sidebar_id' => 'cat_sidebar',
			'pagination' => 'cat_pagination',
			'post_per_page_top' => 0,
		),
		'blog' => array(
			'post_listing'=>'blog_post_listing',
			'show_excerpt' => 'blog_show_excerpt',
			'title_length' => 'blog_title_length',
			'show_name' => 'blog_show_name',
			'show_date' => 'blog_show_date',
			'date_type' => 'blog_date_type',
			'date_format' => 'blog_date_format',
			'date_pretext' => 'blog_post_date_pretext',
			'show_author' => 'blog_show_author',
			'show_views' => 'blog_show_views',
			'show_likes' => 'blog_show_likes',
			'show_comment_count' => 'blog_show_comment_count',
			'show_top_post_grid' => 'show_blog_top_post_grid',
			'top_post_style' => 'blog_top_post_style',
			'sidebar_position' => 'blog_sidebar_position',
			'sidebar_id' => 'blog_sidebar',
			'pagination' => 'blog_pagination',
			'post_per_page_top' => 0,
		),
	);
	
	public function __construct($options=array()){

		if(!class_exists('Gum_html')) return;
	
		$obj = get_queried_object();
		if(!empty($obj->term_id)) $this->cat_id = $obj->term_id;

		$this->set_blog_options();

		// check if we are accessing it from pagebuilder template

		if(!empty($options['pagebuilder'])){

			$this->page_builder = $options['pagebuilder'];
			$this->blog_options['show_top_post_grid'] = 'no';
			
			// Set pagination to standard
			$this->blog_options['pagination'] = 'standard';
		}


	}

	public function set_blog_options(){

		$yes_no_arr = array('no'=> '0', 'yes'=>'1');

		if($this->cat_id){

			$cat_option = Gum_html::get_cat_options($this->cat_id);

			foreach($this->option_mapping['cat'] as $key=>$val){

				if(isset($cat_option[$val])) $this->blog_options[$key] = $cat_option[$val];
			}


		}
		else{
			$blog_global_settings = Gum_html::get_theme_post_options();
			foreach($this->option_mapping['blog'] as $key=>$val){

				if(isset($blog_global_settings[$val])) $this->blog_options[$key] = $blog_global_settings[$val];
			}

		}

		// Get classes
		$this->blog_options['content_class'] = "col-sm-8 col-md-8";
		$this->blog_options['sidebar_class'] = "col-sm-4 col-md-4";
		$this->blog_options['row_class'] = '';

		if(!empty($this->blog_options['sidebar_position'])){

			switch($this->blog_options['sidebar_position']){

				case 'left':
				case 'right':
					$this->blog_options['content_class'] = "col-sm-8 col-md-8";
					$this->blog_options['sidebar_class'] = "col-sm-4 col-md-4";
					$this->blog_options['row_class'] = '';
				break;

				case "none":
					$this->blog_options['content_class'] = "col-sm-12";
					$this->blog_options['sidebar_class'] = "";
					$this->blog_options['row_class'] = 'row gum-row';
					if($this->blog_options['post_listing'] == 'block_3' || $this->blog_options['post_listing'] == 'fullGrid_block_1')  $this->blog_options['row_class'] = '';
				break;

			}

		}
		else $this->blog_options['sidebar_position'] = "right";


		$this->blog_options['args'] = array(

			'class' => '',
 			'show_cat' => $yes_no_arr[$this->blog_options['show_name']],
			'show_date' => $yes_no_arr[$this->blog_options['show_date']],
			'show_author' => $yes_no_arr[$this->blog_options['show_author']],
			'show_views' => $yes_no_arr[$this->blog_options['show_views']],
			'show_likes' => $yes_no_arr[$this->blog_options['show_likes']],
			'show_comment_count' => $yes_no_arr[$this->blog_options['show_comment_count']],
			'date_type' => $this->blog_options['date_type'],
			'custom_date_format' => $this->blog_options['date_format'],
			'show_excerpt' => $yes_no_arr[$this->blog_options['show_excerpt']],
			'title_word_count' => 12,
			'excerpt_word_count' => 200,
			'image_size' => 'gum_400X240',
			'row_class' => 'row gum-row',
			'read_more' => 1
		);
		if($this->blog_options['args']['show_excerpt'] == 0){
			$this->blog_options['args']['read_more'] = 0;
		}

		$block_classes = array(
			'block_2' => 'col-sm-6',
			'block_3' => 'col-sm-6',
		);

		$block_image = array(
			'block_1' => 'gum_780X468',
			'block_2' => 'gum_400X240',
			'block_5' => 'gum_250X320',
			'block_3' => 'gum_350X210',
			'latest_posts_html' => 'gum_780X468',

		);
		if($this->blog_options['sidebar_position'] == 'none'){
			$block_image = array(
				'block_1' => 'full',
				'block_2' => 'gum_400X240',
				'block_3' => 'gum_600X360',

			);
		}
		$this->blog_options['row_class'] = '';
		$this->blog_options['arg_class'] = '';
		if(isset($block_classes[$this->blog_options['post_listing']])) $this->blog_options['arg_class'] .= $block_classes[$this->blog_options['post_listing']]." ";

		if(isset($block_image[$this->blog_options['post_listing']])) $this->blog_options['args']['image_size'] = $block_image[$this->blog_options['post_listing']];

	}
	public function get_blog_options(){
		
		return $this->blog_options;
	}
	
	public function blog($page = 'archive'){

	global $gumtheme_options, $gum_cat_metafields, $gumtheme_translations;

	$cat_id = $this->cat_id;
?>

	<div class="container gum-cat-wrapper gum-cat-wrapper-<?php echo $this->blog_options['post_listing'];?>">
		<?php
			$yes_no_arr = array('no'=> '0', 'yes'=>'1');
			$default_layout = 'full_grid_1';
			if($this->blog_options['show_top_post_grid'] == 'yes' && $page != 'search'){
				
				if(!empty($this->blog_options['top_post_style']) && $this->blog_options['top_post_style'] == 'slider_1')
				$this->blog_options['post_per_page_top'] =10;
				else if($this->blog_options['top_post_style'] == 'posts_grid_2' || $this->blog_options['top_post_style'] == 'posts_grid_3')
				$this->blog_options['post_per_page_top'] =6;
				else
				$this->blog_options['post_per_page_top'] =5;

				$options  = $this->blog_options['args'];
				$options['id'] = $cat_id;
				$options['posts_per_page'] = $this->blog_options['post_per_page_top'];
				$options['post_sort_by'] = 'latest';
				$options['gum_post_offset'] = '';
				$options['category_id'] = $cat_id;
				
				if(!empty($this->blog_options['top_post_style']) && $this->blog_options['top_post_style'] != 'default') $this->blog_options['top_post_style'] = $this->blog_options['top_post_style'];
				else if ( $this->blog_options['top_post_style'] == 'default' ){
					if($page == 'archive' && !empty($gumtheme_options['cat_top_post_style'])) $this->blog_options['top_post_style'] = $gumtheme_options['cat_top_post_style'];
					else if($page == 'index' && !empty($gumtheme_options['blog_top_post_style'])) $this->blog_options['top_post_style'] = $gumtheme_options['blog_top_post_style'];
					else $this->blog_options['top_post_style'] = $default_layout; 
				}
				else $this->blog_options['top_post_style'] = $default_layout; 
				
				$top_post_style = $this->blog_options['top_post_style'];
				
				if($top_post_style =='latest_posts_html'){
					$options['posts_per_page']=4;
					$options['image_size']='gum_780X468';
					$options['show_excerpt']=0;
					$options['read_more']=0;
				}
				if($top_post_style =='slider_1'){
					$options['show_excerpt']=0;
					$options['read_more']=0;
				}
				
				$html = gum_html::$top_post_style($options, $class='');

				if(!empty($html['html'])) echo $html['html'];
			}
			$this->blog_options['content_class']='col-sm-12 col-md-8';
			$this->blog_options['sidebar_class']='col-sm-12 col-md-4';
		?>


		<div class="row gum-row sector">

			<?php  
			$gum_sidebar_id = $this->blog_options['sidebar_id'];
if(empty($gum_sidebar_id) || (isset($gum_sidebar_id) && $gum_sidebar_id == 'default')) $gum_sidebar_id = 'sidebar-1';

$sticky_class='';
$sticky_class = (!empty($gumtheme_options[$gum_sidebar_id.'_sticky']))? ' sticky-sidebars' : '';

				if($this->blog_options['sidebar_position'] == "left") :?>

				<div id="secondary" class="widget-area <?php echo $this->blog_options['sidebar_class']; ?> gum-sidebar-wrapper sticky-wrapper gum-sidebar-left" role="complementary">
					<div class="gum-sidebar <?php echo $sticky_class; ?>">
						<?php dynamic_sidebar( $this->blog_options['sidebar_id'] ); ?>
					</div>
				</div><!-- #secondary -->


			<?php endif; ?>

			<div id="primary" class="content-area <?php echo $this->blog_options['content_class']; ?> gum-cat-<?php echo $this->blog_options['post_listing'];?>">
				<main id="main" class="site-main">


					<?php
						//pagebuilder
						if($this->page_builder){

							 $this->pagebuilder();
						}
						else $this->loop();

					?>



					<?php $this->pagination(); ?>



				</main><!-- #main -->
			</div><!-- #primary -->

			<?php  if($this->blog_options['sidebar_position'] == "right") :?>

				<div id="secondary" class="side-pannels widget-area <?php echo $this->blog_options['sidebar_class']; ?> gum-sidebar-wrapper sticky-wrapper gum-sidebar-right" role="complementary">
					<div class="gum-sidebar <?php echo $sticky_class; ?>">
						<?php dynamic_sidebar( $this->blog_options['sidebar_id'] ); ?>
					</div>
				</div><!-- #secondary -->


			<?php endif; ?>



			</div><!-- row -->
			</div><!-- container -->

	<?php
	}

	public function pagebuilder(){
		global $post;

		if(!empty($post)){
			$meta_fields = get_post_meta($post->ID, 'gum_pagebuilder', true);
			$paged_element = get_post_meta($post->ID, 'gum_has_paged_element', true);
			
			if(!empty($meta_fields)){
				$count = 1;
				foreach($meta_fields as $main_area_key => $main_area){

					if(!empty($main_area['areas'])){

						foreach($main_area['areas'] as $sections){

							foreach($sections as $section_key => $section){
								if(is_array($section) && !empty($section['dynamic_element_type']) && $section['dynamic_element_type'] == $paged_element){
									
									// only show one loop.
									if($count == 1){
										foreach($section as $key => $val) $this->blog_options[$key] = $val;
										gum_get_template_from_area ($this->blog_options);
									}
									
									$count++;
								}
							}

						}
					}
				}
			}
		}


	}
	public function loop(){

		if ( have_posts() ) : ?>
			<?php if(!empty($this->cat_id)): ?>
				<header class="page-header">
					<div class="span"></div>
					<?php
						the_archive_title( '<h1 class="page-title gum-cat-title">', '</h1>' );			
					?>
				</header><!-- .page-header -->
				<?php the_archive_description( '<div class="taxonomy-description">', '</div>' ); ?>
			<?php elseif(is_search()): ?>
				<header class="page-header">
					<h1 class="page-title gum-cat-title"><?php printf( esc_html__( 'Search Results for: %s', 'bloom-gumtheme' ), '<span>' . get_search_query() . '</span>' ); ?></h1>
				</header><!-- .page-header -->
			<?php endif; ?>
			<?php /* Start the Loop */
				$cat_odd_even = "odd";
				$count = 1;
			?>
				<div class="gum-cat-post-inner row <?php echo $this->blog_options['row_class']; ?>">
				<?php
					$count = 1;
					while ( have_posts() ) : the_post(); ?>

					<?php
						/*
						 * Include the Post-Format-specific template for the content.
						 * If you want to override this in a child theme, then include a file
						 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
						 */
						//get_template_part( 'template-parts/content', get_post_format() );
						if(0 == $count % 2 ) $odd_even_class = " gum-block-even ";
						else  $odd_even_class = " gum-block-odd ";

						$this->blog_options['args']['class'] = $this->blog_options['arg_class'].$odd_even_class;
						//$args['large_grid_image_size'] = 'gum_780X468';
						if(!empty($this->blog_options['post_listing'])) $this->blog_options['post_listing_block'] = $this->blog_options['post_listing'];
						else $this->blog_options['post_listing_block'] = 'block_1';

						$post_options = array(
							'post_grid' => $this->blog_options['post_listing_block'],
							'args' => $this->blog_options['args'],
						);
						
						if(class_exists('gum_html')) echo gum_html::category_page_posts($post_options);
						
						if($this->blog_options['post_listing_block'] == 'block_3' && 0 == $count % 2) echo "<div class='clearfix'></div>";

						$count++;
					?>

				<?php endwhile; ?>
				<div class="gum_cat_cf clearfix"></div>
				</div><!-- gum-cat-post-inner -->
				<?php if(class_exists('gum_html')) echo gum_html::simple_spinner(); ?>
		<?php else : 
			if(!empty($this->cat_id)){ 
				global $gumtheme_options;
				$cat_option = Gum_html::get_cat_options($this->cat_id);
				if(!empty($cat_option['show_cat_top_post_grid'])) $show_cat_top_post_grid = $cat_option['show_cat_top_post_grid'];
				if($show_cat_top_post_grid == 'default' && !empty($gumtheme_options['show_cat_top_post_grid'])) $show_cat_top_post_grid = $gumtheme_options['show_cat_top_post_grid'];
			}
		?>

			<?php 
				// If category top header post grid is set to not display then show content none template
				if(!empty($show_cat_top_post_grid)){
					if($show_cat_top_post_grid == 'no') get_template_part( 'template-parts/content', 'none' ); 
				}
				else get_template_part( 'template-parts/content', 'none' );
			?>
		<?php endif; ?>
		<div class="clearfix"></div>

		<?php

	}

	public function pagination(){
		global $gumtheme_translations;
		$pagination = $this->blog_options['pagination'];
		if(!isset($this->blog_options['post_per_page_top'])) $this->blog_options['post_per_page_top'] = 0;
		?>

		<div class="loading_msg"></div>
		<?php if($pagination == 'standard'): ?>
		<?php gum_theme_pagination(); ?>
		<?php elseif($pagination == 'load_more'):
			if(!empty($gumtheme_translations['load_more_text'])) $load_more_text = $gumtheme_translations['load_more_text'];
			else $load_more_text = 'Load more';
		?>
		<div class="gum-load-more-wrapper"><a id="gum-loadmore-cat" class="gum-load-more-btn"><?php echo $load_more_text;?></a></div>
		<?php elseif($pagination == 'infinite'):?>

		<?php endif;?>
		<script>
			<?php

				if(!empty($gumtheme_translations['no_more_posts'])) $no_more_posts_text = $gumtheme_translations['no_more_posts'];
				else $no_more_posts_text = 'No More posts to load.';

				//remove odd_even_class from args
				$this->blog_options['args']['class'] = $this->blog_options['arg_class'];
				$ajax_nonce = wp_create_nonce( "gum-ajax-nonce" ); ?>
				var gumCatpage = {
					'ppp':<?php echo get_option( 'posts_per_page' );?>,
					'cat_id' : '<?php echo $this->cat_id;?>',
					'offset' : <?php echo get_option( 'posts_per_page' ) + $this->blog_options['post_per_page_top'];?>,
					'post_grid' : '<?php echo $this->blog_options['post_listing_block']; ?>',
					'pagination' : '<?php echo $pagination; ?>',
					'args' : '<?php echo maybe_serialize($this->blog_options['args']); ?>',
					'no_more_text' : '<?php echo $no_more_posts_text; ?>'

				}

		</script>

	<?php

	}

}